pub struct UnitEnum<'gc> { /* private fields */ }Trait Implementations
Sourceimpl<'gc> EnumAccess<'gc> for UnitEnum<'gc>
impl<'gc> EnumAccess<'gc> for UnitEnum<'gc>
Sourcetype Error = Error
type Error = Error
The error type that can be returned if some error occurs during
deserialization.
Sourcetype Variant = UnitVariant
type Variant = UnitVariant
The
Visitor that will be used to deserialize the content of the enum
variant.Sourcefn variant_seed<V>(self, seed: V) -> Result<(V::Value, UnitVariant), Error>where
V: DeserializeSeed<'gc>,
fn variant_seed<V>(self, seed: V) -> Result<(V::Value, UnitVariant), Error>where
V: DeserializeSeed<'gc>,
variant is called to identify which variant to deserialize. Read moreAuto Trait Implementations
impl<'gc> Freeze for UnitEnum<'gc>
impl<'gc> !RefUnwindSafe for UnitEnum<'gc>
impl<'gc> !Send for UnitEnum<'gc>
impl<'gc> !Sync for UnitEnum<'gc>
impl<'gc> Unpin for UnitEnum<'gc>
impl<'gc> !UnwindSafe for UnitEnum<'gc>